Een OiRA-risicobeoordeling uitvoeren | OiRA

Thema's

# Een OiRA-risicobeoordeling uitvoeren

## Een nieuwe risicobeoordeling beginnen

Om een nieuwe risicobeoordeling te beginnen, klikt u op de link “Een nieuwe sessie beginnen”.

## Een risicobeoordeling openen

Een eerder begonnen risicobeoordeling kunt u wanneer u maar wilt opvragen via de rubriek “Mijn risicobeoordelingen” op het dashboard. Hier kunt u ook een nieuwe risicobeoordeling beginnen.

Het Dashboard.

## Een risicobeoordeling uitvoeren

Iedere risicobeoordeling bestaat uit verschillende stappen. Deze stappen zijn te zien in het hoofdmenu aan de linkerkant van het scherm:

- Voorbereiding
- Betrokkenheid
- Identificatie + evaluatie
- Actieplan
- Rapport
- Status

Afhankelijk van de door de OiRA-partners/toolontwikkelaars gekozen configuratie kan de structuur per tool verschillen. Bij sommige tools maakt het actieplan deel uit van de stap waarin het risico wordt geïdentificeerd en geëvalueerd. In dat geval ziet het menu aan de linkerkant van het scherm er als volgt uit:

- Voorbereiding
- Betrokkenheid
- Beoordeling
- Rapport
- Status

## Voorbereiding

Bij iedere sessie/tool begint u met “Voorbereiding”. Hier geeft u de risicobeoordeling een naam. Deze naam zal u later helpen onderscheid te maken tussen de verschillende risicobeoordelingen die u met de tool hebt uitgevoerd.

Via de link “Meer informatie over deze tool…” kunt u meer informatie lezen over de geselecteerde tool en de partijen die bij de ontwikkeling van de tool betrokken zijn geweest.

Nadat u op “Start” hebt geklikt, worden er mogelijk nog een aantal aanvullende vragen gesteld. Dit is afhankelijk van de tool die u gebruikt. Dit voorbereidende scherm met “profielvragen” verschijnt alleen bij tools die zijn uitgerust met deze functie.

Hier kunt u:

- Situaties selecteren of overslaan naargelang deze van toepassing zijn op de activiteiten van uw bedrijf. Kies “ja” indien van toepassing.
- Meerdere bedrijfsafdelingen, filialen, winkels enz. vermelden. De gerelateerde risico’s worden voor elke vermelding herhaald.

Het scherm “Profiel” in de rubriek Voorbereiding

De voorbereidingsfase is heel belangrijk, omdat in deze fase het soort bedrijfsactiviteiten en de daarmee samenhangende risico’s nauwkeurig worden gedefinieerd. Nadat u op “Opslaan en doorgaan” hebt geklikt, gaat u naar de volgende rubriek “Betrokkenheid”.

NB Veel tools hebben geen profielvragen, omdat deze niet worden gebruikt voor het doelgerichtheid maken van de tool. In dat geval wordt dit scherm automatisch overgeslagen.

## Betrokkenheid

In deze stap wordt u herinnerd aan het belang van de betrokkenheid van werknemers en worden verschillende manieren gepresenteerd om grote betrokkenheid van werknemers te waarborgen. Hier kunt u de inhoud van de risicobeoordeling downloaden of afdrukken om met uw werknemers te delen. Dit garandeert dat werknemers een bijdrage kunnen leveren aan de beoordeling van de situatie op hun werkplek.

## Beoordeling

In deze stap stelt u vast welke risico’s en problemen van toepassing zijn op uw bedrijf.

NB Afhankelijk van de manier waarop de tool door de OiRA-partner is geconfigureerd, kan de stap “Actieplan” (zie hieronder) in dit scherm zijn geïntegreerd. In dat geval wordt de hele stap aangeduid als “Beoordeling”, en zijn de onder “Actieplan” beschreven onderdelen vermeld bij de identificatie en evaluatie van de verschillende risico’s.

Identificatie en Evaluatie.

Aan de linkerkant van het scherm ziet u onder “Identificatie + Evaluatie”/”Beoordeling” alle onderwerpen/modules die in de tool zijn inbegrepen. Het onderwerp dat u op dat moment bekijkt, is gemarkeerd.

### Identificatie

Voor elk risico moet u beslissen of de beschrijving van een gewenste situatie van toepassing is op uw bedrijf. U kunt antwoorden als volgt:

- Ja: als u op de beschrijving “ja” antwoordt, is er geen verdere actie vereist, omdat er volgens u geen risico aanwezig is.
- Nee: als u op de beschrijving “nee” antwoordt, moet er verdere actie worden ondernomen. U wordt verzocht een besluit te nemen over specifieke maatregelen.
- Niet van toepassing: sommige risicobeschrijvingen bieden de optie om “niet van toepassing” te kiezen wanneer het risico niet relevant is voor uw bedrijf.

Onder elke beschrijving wordt gewoonlijk meer informatie gegeven over de specifieke risico’s:

- Informatie: een korte beschrijving, soms vergezeld van afbeeldingen, waarin meer bijzonderheden worden verstrekt over het risico.
- Bronnen: aanvullende informatie over het risico, zoals verwijzingen naar wetgeving en beleid. Soms vindt u hier ook documenten die u kunt raadplegen.
- Opmerkingen: u kunt hier uw eigen opmerkingen plaatsen, die aan het eind van de beoordeling in uw rapport worden opgenomen.

Nadat u op een risicobeschrijving hebt gereageerd, wordt het menu aan de linkerkant bijgewerkt met een kleurensymbool om aan te geven dat u:

- positief hebt geantwoord (groen vinkje)
- negatief hebt geantwoord (rood kruisje)
- uw antwoord hebt uitgesteld (oranje vraagteken)

Voor onbeantwoorde vragen blijft het grijze symbool staan.

### Evaluatie

In deze stap evalueert u de prioriteit van een risico dat u hebt vastgesteld.

Een risico evalueren.

NB In sommige OiRA-tools wordt de stap Evaluatie niet getoond. Dit is afhankelijk van de manier waarop de nationale OiRA-partner/toolontwikkelaar zijn specifieke OiRA-tool heeft geconfigureerd.

Als u hebt aangegeven dat er een risico aanwezig is (met een rood kruisje), verschijnt de rubriek Evaluatie. Afhankelijk van de voor elk risico vastgestelde evaluatiemethode wordt u verzocht:

- een inschatting te maken van de prioriteit: hoog, gemiddeld of laag

De prioriteit van een risico vaststellen.

OF

- een paar vragen te beantwoorden over de frequentie, ernst en waarschijnlijkheid van het risico, zodat op basis van uw antwoorden de prioriteit kan worden vastgesteld.

Risicovariabelen vaststellen.

### Sectorgebonden prioritaire risico’s:

Sommige risico’s worden als heel belangrijk beschouwd door de nationale partner/toolontwikkelaar die de specifieke OiRA-tool heeft ontwikkeld. U hoeft dergelijke “prioritaire risico’s” niet in te schatten, omdat hun prioriteit automatisch als “hoog” is ingesteld.

Prioritaire risico’s.

### Bedrijfsspecifieke risico’s

Nadat u klaar bent met het beantwoorden van alle risicovragen onder “Identificatie + Evaluatie”/”Beoordeling”, verschijnt de facultatieve rubriek “Overige risico’s”. Hier kunt u met de knop “Een bedrijfsspecifiek risico toevoegen” zelf risico’s toevoegen.

Als er op uw werkplek / in uw bedrijf risico’s zijn die niet worden genoemd in de tool, moet u deze hier zelf toevoegen. Deze risico’s mogen door u volledig naar eigen inzicht worden gedefinieerd/beschreven.

Bedrijfsspecifieke risico’s.

Voor een “bedrijfsspecifiek risico” geldt hetzelfde als voor de risico’s die worden aangedragen door de OiRA-tool, maar vanzelfsprekend moet u de tekst zelf schrijven. Deze tekst moet ten minste bestaan uit een korte vermelding van een problematische situatie, maar u mag ook een langere beschrijving geven. U kunt ook een afbeelding uploaden om een bepaalde situatie te illustreren.

Net als bij de reguliere risico’s moet u aangeven of het risico al dan niet aanwezig is. Op deze manier kunt u de bedrijfsspecifieke risico’s afvinken, zodra deze succesvol zijn aangepakt, en deze in uw risicobeoordeling opslaan voor documentatiedoeleinden.

U kunt zo veel bedrijfsspecifieke risico’s toevoegen als u nodig vindt.

Een bedrijfsspecifiek risico toevoegen.

## Actieplan

In deze stap beslist u welke maatregelen u wilt nemen om de risico’s die u eerder hebt vastgesteld weg te nemen of te beperken.

NB Zoals hierboven al opgemerkt, wordt het actieplan in het menu aan de linkerkant van het scherm als afzonderlijke stap weergegeven of wordt het onder ieder geïdentificeerd risico vermeld. In het laatste geval valt deze stap onder de rubriek “Beoordeling” in het menu en bestaat deze zowel uit risicobeschrijvingen als mogelijke maatregelen.

Welke versie u ziet, is afhankelijk van de door de nationale OiRA-partner/toolontwikkelaar gekozen configuratie.

### Geïntegreerd actieplan

Geïntegreerd actieplan.

Als u een vraag met “nee” hebt beantwoordt, verschijnt de actieplanmodule in de rubriek “Maatregelen”.

U kunt uit een lijst met door het systeem voorgestelde maatregelen kiezen of uw eigen maatregelen beschrijven.

### Actieplan als afzonderlijke stap

Wanneer het actieplan een afzonderlijke stap is, is het toegankelijk via het menu aan de linkerkant van het scherm.

Klik op de knop “Actieplan aanmaken” om met uw plan te beginnen.

In de stap Actieplan toont het menu aan de linkerkant van het scherm alleen de risico’s die voor verdere actie zijn gemarkeerd, omdat de andere risico’s als niet-aanwezige risico’s zijn afgevinkt.

Voor elk risico waarvoor u tijdens de evaluatieprocedure vragen met “nee” hebt beantwoord, alsook voor geprioriteerde risico’s (ongeacht of het antwoord positief of negatief was voor deze risico’s), wordt u verzocht maatregelen te definiëren.

Een risico in het actieplan.

U kunt uit een lijst van door het systeem voorgestelde maatregelen kiezen of uw eigen maatregelen definiëren.

#### Uw eigen maatregel toevoegen

Een extra maatregel toevoegen.

Gebruik de knop “Een maatregel toevoegen” om te beginnen met de beschrijving van een preventieve maatregel. U moet daarbij:

- Een beschrijving geven van de te volgen algemene aanpak om het risico weg te nemen of te verminderen.
- Eventueel een beschrijving geven van het vereiste niveau van deskundigheid en/of de vereiste vaardigheden (hier kunt u bijvoorbeeld toevoegen of er een specifieke opleiding of externe expertise vereist is om dit risico aan te pakken).
- Informatie geven over de persoon of personen die verantwoordelijk is/zijn voor de uitvoering van de maatregelen.
- Indien van toepassing, een begroting vaststellen.
- Eventueel de geplande start- en einddata voor de uitvoering van de maatregel vermelden.

U kunt zo veel maatregelen toevoegen als nodig is.

#### Standaardmaatregelen toevoegen

Afhankelijk van de manier waarop de OiRA-partner/toolontwikkelaar de tool heeft geconfigureerd, zijn er vooraf gedefinieerde maatregelen beschikbaar voor individuele risico’s. Om een of meer vooraf gedefinieerde maatregelen te kiezen, klikt u op de knop “Standaardmaatregelen kiezen”.

Er verschijnt een pop-upmenu met alle voorgestelde maatregelen. Klik naast de maatregelen die u wilt gebruiken op de knop “Toevoegen”.

De vooraf gedefinieerde maatregelen worden vervolgens in uw actieplan opgenomen. De beschrijving van de te ondernemen actie staat vast, maar de andere velden (verantwoordelijkheid, begroting, data) kunnen en moeten nog door u worden ingevuld.

Standaardmaatregelen toevoegen.

Zowel de standaardmaatregelen als de door u gedefinieerde maatregelen kunnen op elk gewenst moment weer worden verwijderd.

## Rapport

Na voltooiing van het actieplan kunt u een rapport opstellen.

Als u een opmerking wilt opnemen in het rapport, kunt u hier uw tekst intypen en opslaan.

Opmerking over het rapport.

Kijk hier voor meer informatie over de verschillende rapporten en hoe u deze kunt gebruiken.

## Status

In het kleine taartdiagram in het menu aan de linkerkant van het scherm ziet u hoe ver u bent gevorderd in de tool.

In de rubriek “Status” wordt een overzicht gegeven van het aantal risico’s dat u hebt vastgesteld, voor hoeveel van deze risico’s u hebt besloten maatregelen te nemen, en op hoeveel risico’s/beschrijvingen u nog niet hebt gereageerd.

De statuspagina.

Wanneer u het statusscherm opent, ziet u uw vorderingen in de verschillende modules. Dit kan u helpen om vast te stellen waar u nog risico’s moet beoordelen of maatregelen moet nemen met betrekking tot de risico’s die u hebt vastgesteld.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More